@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-04'; # DATE
+our $DATE = '2022-07-16'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 sub meta {
     +{
@@ -19,6 +19,12 @@ sub meta {
                 default => 'shell',
             },
         },
+        examples => [
+            {value=>"foo"},
+            {value=>"foo # comment", filtered_value=>"foo"},
+            {value=>"foo # comment", filter_args=>{style=>"cpp"}},
+            {value=>"foo // comment", filter_args=>{style=>"cpp"}, filtered_value=>"foo"},
+        ],
     };
 }
 
@@ -59,13 +65,35 @@ Data::Sah::Filter::perl::Str::remove_comment - Remove comment
 
 =head1 VERSION
 
-This document describes version 0.010 of Data::Sah::Filter::perl::Str::remove_comment (from Perl distribution Data-Sah-Filter), released on 2022-07-04.
+This document describes version 0.011 of Data::Sah::Filter::perl::Str::remove_comment (from Perl distribution Data-Sah-Filter), released on 2022-07-16.
 
 =head1 SYNOPSIS
 
-Use in Sah schema's C<prefilters> (or C<postfilters>) clause:
+=head2 Using in Sah schema's C<prefilters> (or C<postfilters>) clause
 
- ["str","prefilters",["Str::remove_comment"]]
+ ["str","prefilters",[["Str::remove_comment"]]]
+
+=head2 Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ 
+ my $schema = ["str","prefilters",[["Str::remove_comment"]]];
+ my $validator = gen_validator($schema);
+ if ($validator->($some_data)) { print 'Valid!' }
+
+=head2 Using with L<Data::Sah:Filter> directly:
+
+ use Data::Sah::Filter qw(gen_filter);
+
+ my $filter = gen_filter([["Str::remove_comment"]]);
+ my $filtered_value = $filter->($some_data);
+
+=head2 Sample data and filtering results
+
+ "foo" # valid, unchanged
+ "foo # comment" # valid, becomes "foo"
+ "foo # comment" # filtered with args {style=>"cpp"}, valid, unchanged
+ "foo // comment" # filtered with args {style=>"cpp"}, valid, becomes "foo"
 
 =for Pod::Coverage ^(meta|filter)$
 
